@@ -11,8 +11,10 @@
 #include <stdlib.h>
 #include <unistd.h>	/* for isatty() */
 
+#if !defined(TRUE)
 #define FALSE	0
 #define TRUE	1
+#endif
 
 #define PNG_INTERNAL
 #include "gif2png.h"
@@ -132,7 +134,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
     png_uint_16 histogr[MAXCMSIZE];
     unsigned long hist_maxvalue;
     int passcount;
-    int errorcount = 0;
+    int errtype, errorcount = 0;
     png_text software;
 
     /* these volatile declarations prevent gcc warnings ("variable might be
@@ -287,10 +289,36 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	return 1;
     }
 
-    /* initialize PNG writing */
-    png_write_init(png_ptr);
-    png_info_init(info_ptr);
+
+    /* Create and initialize the png_struct with the desired error handler
+     * functions.  If you want to use the default stderr and longjump method,
+     * you can supply NULL for the last three parameters.  We also check that
+     * the library version is compatible with the one used at compile time,
+     * in case we are using dynamically linked libraries.  REQUIRED.
+     */
+    png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING,
+				      (void *)NULL, NULL, NULL);
+
+    if (png_ptr == NULL)
+	return(2);
+
+    /* Allocate/initialize the image information data.  REQUIRED */
+    info_ptr = png_create_info_struct(png_ptr);
+    if (info_ptr == NULL)
+    {
+	png_destroy_write_struct(&png_ptr,  (png_infopp)NULL);
+	return(2);
+    }
+
+    /* if errtype is not 1, this was generated by fatal() */ 
+    if ((errtype = setjmp(png_jmpbuf(png_ptr)))) {
+	png_destroy_write_struct(&png_ptr, &info_ptr);
+	return errtype;
+    }
+
+    /* use standard C streams */
     png_init_io(png_ptr, fp);
+
     if(optimize)
        png_set_compression_level(png_ptr, Z_BEST_COMPRESSION);
 
@@ -498,7 +526,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 
 	case GIFapplication:
 	    data = access_data(s, 0, s->size);
-	    png_write_chunk_start(png_ptr, "gIFx", s->size);
+	    png_write_chunk_start(png_ptr, (unsigned char *)"gIFx", s->size);
 	    png_write_chunk_data(png_ptr, data, s->size);
 	    png_write_chunk_end(png_ptr);
 	    break;
@@ -543,7 +571,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	    buffer[2] = data[2];
 	    buffer[3] = data[1];
 
-	    png_write_chunk(png_ptr, "gIFg", buffer, 4);
+	    png_write_chunk(png_ptr, (unsigned char *)"gIFg", buffer, 4);
 	    break;
 
 	default:
@@ -553,10 +581,9 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	s = s->next;
     }
     png_write_end(png_ptr, info_ptr);
-    png_write_destroy(png_ptr);
 
-    free(png_ptr);
-    free(info_ptr);
+    /* clean up after the write, and free any memory allocated */
+    png_destroy_write_struct(&png_ptr, &info_ptr);
 
     return errorcount;
 }
