@@ -29,7 +29,7 @@ can even recover data from corrupted GIFs.<p>
 
 The distribution also includes a Python script, web2png, that will convert
 entire web hierarchies (images and HTML or PHP pages). The script
-requires Python 1.5.2.<p>
+requires Python 1.5.2 or later.<p>
 
 The current version is ${version}. The program has actually been functional and
 stable for four years. See the <a href="NEWS">NEWS</a> file for more.<p>
@@ -48,7 +48,8 @@ Binaries of a Win32 port <a href="http://exe2bin.com/gif2png-win32/">are
 available</a>.<p>
 
 Note: Some ImageMagick 4.2.x versions have a bug displaying grayscale 
-PNGs that makes it look like gif2png is broken.  It's not.<p>
+PNGs that makes it look like gif2png is broken.  It's not.  The bug 
+has been fixed, at least as of 5.2.2.<p>
 
 <H1>History</H1>
 
@@ -67,12 +68,12 @@ a change in the license terms to use the libpng/zlib license.<p>
 <H1>Patent issues</H1>
 
 The GIF format is encumbered by a <a
-href="http://www.patents.ibm.com/details?pn=US04558302__">Unisys
+href="http://www.delphion.com/details?pn=US04558302__">Unisys
 patent</a> for the Lempel-Ziv-Welch compression algorithm.  Use of any
 GIF image generator not licensed by Unisys can make you liable to
 lawsuit.  Unisys apparently refuses to issue licenses for use of LZW
 in open-source programs, and in 1999 <a
-href="http://corp2.unisys.com/LeadStory/lzw-license.html">stated</a>
+href="http://mfz.8k.com/lzw-license.html">stated</a>
 that its policy is to require a \$5000 fee from websites that carry GIF
 images made by unlicensed software -- even nonprofit websites created
 and displayed with free software.<p>
